@@ -189,9 +189,11 @@ FetCamImage::FetCamImage(
 
 FetCamImage::~FetCamImage()
 {
+/*
   QSettings settings("pietrzak.org", "Fettuccine");
  
   settings.setValue("currentWebcamID", selectorDialog->getCurrentID());
+*/
 
   if (messenger) delete messenger;
   if (loadFileDialog) delete loadFileDialog;
@@ -204,6 +206,7 @@ FetCamImage::~FetCamImage()
 }
 
 
+/*
 void FetCamImage::loadFirstImage()
 {
   QSettings settings("pietrzak.org", "Fettuccine");
@@ -219,6 +222,20 @@ void FetCamImage::loadFirstImage()
     selectorDialog->chooseItem(0);
   }
 }
+*/
+
+
+void FetCamImage::loadImage(
+  int id)
+{
+  selectorDialog->chooseItem(id);
+}
+
+
+int FetCamImage::getCurrentID() const
+{
+  return selectorDialog->getCurrentID();
+}
 
 
 QSize FetCamImage::sizeHint() const
@@ -296,6 +313,8 @@ void FetCamImage::retrieveImage()
 }
 
 
+// "updateWidget" is called when the "finished" signal is emitted from
+// the QNetworkAccessManager object:
 void FetCamImage::updateWidget(
   QNetworkReply *reply)
 {
@@ -362,7 +381,11 @@ void FetCamImage::updateWidget(
   }
 
   reply->deleteLater();
-  currentReply = 0; // this is a hack
+  if (currentReply)
+  {
+    currentReply->deleteLater();
+    currentReply = 0;
+  }
   retrievalInProgress = false;
 }
 
@@ -433,6 +456,7 @@ void FetCamImage::loadWebcam(
   maxMJpegListSize = item->getMaxImages();
   slideshowTimerInterval = item->getSlideshowDelay() * 1000;
   emit newWebcamName(item->getName());
+  emit newWebcamID(selectorDialog->getCurrentID());  // fix this!
   currentTimerInterval = item->getRefreshRate() * 1000;
 
   // Only load webcam if we are not currently paused:
@@ -728,7 +752,6 @@ void FetCamImage::handleReplySslErrors(
 
 void FetCamImage::parseMJpegData()
 {
-
   if (mjpegState == FinishedParsing_State)
   {
     // Nothing more to do.
@@ -947,10 +970,10 @@ void FetCamImage::parseMJpegImage()
         if (currentReply)
         {
           currentReply->abort();
-          currentReply->deleteLater();
-          currentReply = 0;
-          retrievalInProgress = false;
-          startupSlideshow();
+//          currentReply->deleteLater();
+//          currentReply = 0;
+//          retrievalInProgress = false;
+//          startupSlideshow();
         }
       }
     }
