@@ -63,7 +63,11 @@ public:
 
   ~FetCamImage();
 
-  void loadFirstImage();
+//  void loadFirstImage();
+
+  void loadImage(int id);
+
+  int getCurrentID() const;
 
   QSize sizeHint() const;
 
@@ -96,6 +100,7 @@ public slots:
 
 signals:
   void newWebcamName(QString);
+  void newWebcamID(int); // need to fix this!
   void pauseDisplay();
 
 protected:
