@@ -6,13 +6,17 @@
 
 
 FetWidgetSettingsDialog::FetWidgetSettingsDialog(
-  QWidget *parent)
-  : QDialog(parent),
+  int width,
+  int height)
+  : QDialog(0),
     ui(new Ui::FetWidgetSettingsDialog),
     aboutDialog(0)
 {
   ui->setupUi(this);
 
+  ui->widthSpinBox->setValue(width);
+  ui->heightSpinBox->setValue(height);
+
   aboutDialog = new FetAboutDialog();
 }
 
