@@ -15,8 +15,9 @@ class FetWidgetSettingsDialog : public QDialog
   Q_OBJECT
   
 public:
-  explicit FetWidgetSettingsDialog(
-    QWidget *parent = 0);
+  FetWidgetSettingsDialog(
+    int width,
+    int height);
 
   ~FetWidgetSettingsDialog();
 
