@@ -74,6 +74,12 @@ int main(int argc, char *argv[])
       &widget,
       SLOT(showSettingsDialog()));
 
+    QObject::connect(
+      adaptor,
+      SIGNAL(homescreenChanged(bool)),
+      &widget,
+      SLOT(widgetCurrentlyVisible(bool)));
+
     widget.show();
 
     return app.exec();
@@ -85,6 +91,7 @@ int main(int argc, char *argv[])
 
 #ifdef MAEMO_OS
 //    mainWindow.setAttribute(Qt::WA_AutoOrientation, true);
+  // 130 is auto orientation:
   mainWindow.setAttribute(static_cast<Qt::WidgetAttribute>(130), true);
   mainWindow.showMaximized();
 #else
