@@ -80,6 +80,9 @@ private slots:
 
   void pauseViewer();
 
+  void updateWebcamID(
+    int id);
+
 private:
   void returnToControls();
 
